@@ -5,7 +5,7 @@ using namespace Rcpp;
 
 double log_sum_exp_2(double x, double y);
 arma::vec real_to_simplex(const arma::vec y);
-const double TOL = std::sqrt(DOUBLE_EPS);
+const double TOL = std::sqrt(DBL_EPSILON);
 double lprior(const arma::vec prob, const arma::vec alpha);
 
 //' Multinomial pdf
